#
# spec file for package pentobi
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pentobi
Version:        21.0
Release:        bp156.2.9
Summary:        Program to play the board game Blokus
License:        GPL-3.0-only
Group:          Amusements/Games/Strategy/Other
URL:            http://pentobi.sourceforge.net/
Source:         http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.xz
BuildRequires:  cmake >= 3.18
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  extra-cmake-modules
BuildRequires:  gcc-c++
BuildRequires:  itstool
BuildRequires:  kio-devel
BuildRequires:  libqt5-linguist-devel
BuildRequires:  libxslt-tools
BuildRequires:  pkgconfig
BuildRequires:  rsvg-convert
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core) >= 5.15
BuildRequires:  pkgconfig(Qt5QuickControls2)
BuildRequires:  pkgconfig(Qt5WebView)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(appstream)
Requires(post): hicolor-icon-theme
Requires(post): update-desktop-files
Requires(postun):hicolor-icon-theme
Requires(postun):update-desktop-files

%description
Pentobi is a computer opponent for the board game Blokus with
support for Classic, Duo, Junior, Trigon, and Nexos game variants.
Different levels of playing strength are available. Pentobi can
save and load games along with comments and move variations.

%package kde-thumbnailer
Summary:        KDE thumbnailer for Pentobi game files
Group:          Amusements/Games/Strategy/Other
Enhances:       dolphin

%description kde-thumbnailer
This package contains a KDE plugin to display thumbnails of
Pentobi game files.

%prep
%setup -q

%build
%cmake -DKDE_INSTALL_USE_QT_SYS_PATHS=ON \
       -DPENTOBI_BUILD_KDE_THUMBNAILER=ON \
       -DPENTOBI_BUILD_TESTS=ON
%make_jobs VERBOSE=1

%install
%cmake_install

%files
%license LICENSE.md
%doc AUTHORS.md NEWS.md README.md
%{_bindir}/pentobi
%{_datadir}/applications/io.sourceforge.pentobi.desktop
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/mime/packages/*.xml
%{_mandir}/man6/pentobi.6%{?ext_man}
%{_mandir}/*/man6/pentobi.6%{?ext_man}
%{_datadir}/metainfo/io.sourceforge.pentobi.appdata.xml

%files kde-thumbnailer
%{_bindir}/pentobi-thumbnailer
%dir %{_datadir}/thumbnailers
%{_datadir}/thumbnailers/pentobi.thumbnailer
%{_libdir}/qt5/plugins/pentobi-thumbnail.so
%{_datadir}/kservices5/pentobi-thumbnail.desktop
%{_mandir}/man6/pentobi-thumbnailer.6%{?ext_man}
%{_mandir}/*/man6/pentobi-thumbnailer.6%{?ext_man}

%changelog
* Wed May 18 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 21.0
  * New help viewer implementation, which includes DocBook files
    in the resources. This avoids using an external browser, which
    did not work with all installation directories on Ubuntu 21.10
    because Firefox and Chromium have restricted access to local
    files, or using WebView, which is not supported on all Linux
    architectures or in Qt 6.0/6.1.
  * Fixed visibility of labels on Callisto 1x1-piece in dark theme.
  * Fixed rendering issues on Android with Qt 6.3.0.
  * Fixed detection of loaded files or autosaved games modified by
    another application.
* Sun Jan 23 2022 Martin Hauke <mardnh@gmx.de>
- Update to versino 20.0
  * More general workaround to avoid crashes with Qt 5.15 related
    to storing QDateTime in QSettings.
  * Workarounds for bugs in Qt 6.2 that sometimes caused wrong
    positions of unplayed pieces.
  * Install application and mimetype bitmap icons for multiple
    sizes.
  * Show error message if launching web browser failed.
  * Minimum required CMake version is now 3.18.
* Mon Dec  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 19.1
  * Workaround for a crash at exit in some situations.
  * Dialog for starting rated game was not shown after accepting a
    dialog to discard current game.
  * Avoid deprecated mimetypes tag in AppStream file.
  * Avoid warnings with Qt 6 caused by deprecated signal handler
    syntax.
* Sat Apr 17 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 19.0
  * The minimum required Qt version is now 5.15.
  * Support compilation with Qt 6.
  * The desktop version now always displays the manual with an
    external browser, which removes the dependency on the Qt
    WebView library and the compilation option
    PENTOBI_OPEN_HELP_EXTERNALLY.
  * The Qt SVG library is no longer needed.
  * Loading game files in encodings other than UTF-8 is no
    longer supported.
* Thu Mar  4 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 18.5
  * Require GNU gettext >=0.19.6, which has built-in support for
    AppData, such the appstream package is no longer needed for
    compilation.
  * Added missing include that broke the compilation with GCC 11
  * Complete Russian translation of the manual.
* Sat Nov 28 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 18.4
  * Avoid unnecessary dependency on QtQml QML module.
  * Aborting computer play with the Stop button did not work
    reliably when the computer played multiple colors at low
    levels.
  * New Russian translation of manual.
* Wed Nov  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 18.3
  * Made opening of recent rated games from rating dialog work
    again.
  * New Russian UI translation.
  * Menu shortcuts are no longer supported.
* Sun Oct 11 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 18.2
  * Fixed truncated submenu in desktop version with Qt 5.15.
  * Updated bugtracker link.
* Fri Jun 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 18.1
  * Fixed compilation with Qt 5.15.
  * Updated AndroidManifest.xml for usage with Qt 5.15.
  * HTML manual generation failed with older versions of DocBook XSL.
* Mon May 11 2020 Martin Hauke <mardnh@gmx.de>
- Updat to version 18.0
  * The minimum required Qt version is now 5.12.
  * Fixed crash if application was closed while game analysis was
    running.
  * Added missing include that broke the compilation with GCC 10
    if compiled with PENTOBI_BUILD_GTP=1.
* Wed Nov  6 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 17.3
  * Don't use Fusion style on desktop anymore because it is
    currently broken on some Linux distributions (QTBUG-77107).
  * Added more search hints for location of DocBook XSL.
- Update to version 17.2
  * New Spanish translation
  * New Game button and menu item were not enabled if no moves were
    played but an analysis graph existed (e.g. after analyzing a
    game and then undoing all moves).
  * Clear autosaved analysis if autosaved game corresponded to a
    file that no longer exists.
* Thu Jun 13 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release, version 17.1
  * Move generation hung if a move generation using search was
    aborted and the next move generation used the opening book.
  * Added search hint for DocBook XSL for compilation on OpenSUSE.
- Remove patch (fixed upstream):
  * pentobi-add-proper-docbook-path.patch
* Thu Jun  6 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release, version 17.0
  * see /usr/share/doc/packages/pentobi/NEWS for all changes
  * Add patch:
  - pentobi-add-proper-docbook-path.patch
    Add hint path so cmake can find html/chunk.xsl
* Wed Apr 17 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release, version 16.3
  * see /usr/share/doc/packages/pentobi/NEWS for all changes
* Thu Jul 19 2018 mardnh@gmx.de
- Specfile cleanup
* Fri Jun 29 2018 huaren.zhong@gmail.com
- Rebuild for Fedora
* Mon Jan  4 2016 juhaninumminen0@gmail.com
- Created by borrowing from existing pentobi.spec files
- Add subpackage kde-thumbnailer
- Build with -O3 to make higher levels faster
